==> openflowplugin-extension-nicira-0.7.1-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/action/rev140714/dst/choice/grouping/dst/choice/DstOfArpTpaCaseBuilder.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.dst.choice.grouping.dst.choice;
import com.google.common.base.MoreObjects;
import com.google.common.collect.ImmutableMap;
import java.lang.Boolean;
import java.lang.Class;
import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.util.Collections;
import java.util.HashMap;
import java.util.Map;
import java.util.Objects;
import org.opendaylight.yangtools.concepts.Builder;
import org.opendaylight.yangtools.yang.binding.Augmentation;
import org.opendaylight.yangtools.yang.binding.AugmentationHolder;
import org.opendaylight.yangtools.yang.binding.CodeHelpers;
import org.opendaylight.yangtools.yang.binding.DataObject;

/**
 * Class that builds {@link DstOfArpTpaCaseBuilder} instances.
 *
 * @see DstOfArpTpaCaseBuilder
 *
 */
public class DstOfArpTpaCaseBuilder implements Builder<DstOfArpTpaCase> {

    private Boolean _ofArpTpa;


    Map<Class<? extends Augmentation<DstOfArpTpaCase>>, Augmentation<DstOfArpTpaCase>> augmentation = Collections.emptyMap();

    public DstOfArpTpaCaseBuilder() {
    }
    public DstOfArpTpaCaseBuilder(org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxmOfArpTpaGrouping arg) {
        this._ofArpTpa = arg.isOfArpTpa();
    }

    public DstOfArpTpaCaseBuilder(DstOfArpTpaCase base) {
        this._ofArpTpa = base.isOfArpTpa();
        if (base instanceof DstOfArpTpaCaseImpl) {
            DstOfArpTpaCaseImpl impl = (DstOfArpTpaCaseImpl) base;
            if (!impl.augmentation.isEmpty()) {
                this.augmentation = new HashMap<>(impl.augmentation);
            }
        } else if (base instanceof AugmentationHolder) {
            @SuppressWarnings("unchecked")
            Map<Class<? extends Augmentation<DstOfArpTpaCase>>, Augmentation<DstOfArpTpaCase>> aug =((AugmentationHolder<DstOfArpTpaCase>) base).augmentations();
            if (!aug.isEmpty()) {
                this.augmentation = new HashMap<>(aug);
            }
        }
    }

    /**
     * Set fields from given grouping argument. Valid argument is instance of one of following types:
     * <ul>
     * <li>org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxmOfArpTpaGrouping</li>
     * </ul>
     *
     * @param arg grouping object
     * @throws IllegalArgumentException if given argument is none of valid types
    */
    public void fieldsFrom(DataObject arg) {
        boolean isValidArg = false;
        if (arg instanceof org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxmOfArpTpaGrouping) {
            this._ofArpTpa = ((org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxmOfArpTpaGrouping)arg).isOfArpTpa();
            isValidArg = true;
        }
        CodeHelpers.validValue(isValidArg, arg, "[org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxmOfArpTpaGrouping]");
    }

    public Boolean isOfArpTpa() {
        return _ofArpTpa;
    }
    
    @SuppressWarnings("unchecked")
    public <E extends Augmentation<DstOfArpTpaCase>> E augmentation(Class<E> augmentationType) {
        return (E) augmentation.get(CodeHelpers.nonNullValue(augmentationType, "augmentationType"));
    }

    
    public DstOfArpTpaCaseBuilder setOfArpTpa(final Boolean value) {
        this._ofArpTpa = value;
        return this;
    }
    
    public DstOfArpTpaCaseBuilder addAugmentation(Class<? extends Augmentation<DstOfArpTpaCase>> augmentationType, Augmentation<DstOfArpTpaCase> augmentationValue) {
        if (augmentationValue == null) {
            return removeAugmentation(augmentationType);
        }
    
        if (!(this.augmentation instanceof HashMap)) {
            this.augmentation = new HashMap<>();
        }
    
        this.augmentation.put(augmentationType, augmentationValue);
        return this;
    }
    
    public DstOfArpTpaCaseBuilder removeAugmentation(Class<? extends Augmentation<DstOfArpTpaCase>> augmentationType) {
        if (this.augmentation instanceof HashMap) {
            this.augmentation.remove(augmentationType);
        }
        return this;
    }

    @Override
    public DstOfArpTpaCase build() {
        return new DstOfArpTpaCaseImpl(this);
    }

    private static final class DstOfArpTpaCaseImpl implements DstOfArpTpaCase {
    
        private final Boolean _ofArpTpa;
    
        private Map<Class<? extends Augmentation<DstOfArpTpaCase>>, Augmentation<DstOfArpTpaCase>> augmentation = Collections.emptyMap();
    
        DstOfArpTpaCaseImpl(DstOfArpTpaCaseBuilder base) {
            this._ofArpTpa = base.isOfArpTpa();
            this.augmentation = ImmutableMap.copyOf(base.augmentation);
        }
    
        @Override
        public Class<DstOfArpTpaCase> getImplementedInterface() {
            return DstOfArpTpaCase.class;
        }
    
        @Override
        public Boolean isOfArpTpa() {
            return _ofArpTpa;
        }
        
        @SuppressWarnings("unchecked")
        @Override
        public <E extends Augmentation<DstOfArpTpaCase>> E augmentation(Class<E> augmentationType) {
            return (E) augmentation.get(CodeHelpers.nonNullValue(augmentationType, "augmentationType"));
        }
    
        private int hash = 0;
        private volatile boolean hashValid = false;
        
        @Override
        public int hashCode() {
            if (hashValid) {
                return hash;
            }
        
            final int prime = 31;
            int result = 1;
            result = prime * result + Objects.hashCode(_ofArpTpa);
            result = prime * result + Objects.hashCode(augmentation);
        
            hash = result;
            hashValid = true;
            return result;
        }
    
        @Override
        public boolean equals(Object obj) {
            if (this == obj) {
                return true;
            }
            if (!(obj instanceof DataObject)) {
                return false;
            }
            if (!DstOfArpTpaCase.class.equals(((DataObject)obj).getImplementedInterface())) {
                return false;
            }
            DstOfArpTpaCase other = (DstOfArpTpaCase)obj;
            if (!Objects.equals(_ofArpTpa, other.isOfArpTpa())) {
                return false;
            }
            if (getClass() == obj.getClass()) {
                // Simple case: we are comparing against self
                DstOfArpTpaCaseImpl otherImpl = (DstOfArpTpaCaseImpl) obj;
                if (!Objects.equals(augmentation, otherImpl.augmentation)) {
                    return false;
                }
            } else {
                // Hard case: compare our augments with presence there...
                for (Map.Entry<Class<? extends Augmentation<DstOfArpTpaCase>>, Augmentation<DstOfArpTpaCase>> e : augmentation.entrySet()) {
                    if (!e.getValue().equals(other.augmentation(e.getKey()))) {
                        return false;
                    }
                }
                // .. and give the other one the chance to do the same
                if (!obj.equals(this)) {
                    return false;
                }
            }
            return true;
        }
    
        @Override
        public String toString() {
            final MoreObjects.ToStringHelper helper = MoreObjects.toStringHelper("DstOfArpTpaCase");
            CodeHelpers.appendValue(helper, "_ofArpTpa", _ofArpTpa);
            CodeHelpers.appendValue(helper, "augmentation", augmentation.values());
            return helper.toString();
        }
    }
}

==> openflowplugin-extension-nicira-0.7.3-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/action/rev140714/dst/choice/grouping/dst/choice/DstOfArpTpaCaseBuilder.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.dst.choice.grouping.dst.choice;
import com.google.common.base.MoreObjects;
import com.google.common.collect.ImmutableMap;
import java.lang.Boolean;
import java.lang.Class;
import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.SuppressWarnings;
import java.util.Collections;
import java.util.HashMap;
import java.util.Map;
import java.util.Objects;
import org.opendaylight.yangtools.concepts.Builder;
import org.opendaylight.yangtools.yang.binding.Augmentation;
import org.opendaylight.yangtools.yang.binding.AugmentationHolder;
import org.opendaylight.yangtools.yang.binding.CodeHelpers;
import org.opendaylight.yangtools.yang.binding.DataObject;

/**
 * Class that builds {@link DstOfArpTpaCaseBuilder} instances.
 *
 * @see DstOfArpTpaCaseBuilder
 *
 */
public class DstOfArpTpaCaseBuilder implements Builder<DstOfArpTpaCase> {

    private Boolean _ofArpTpa;


    Map<Class<? extends Augmentation<DstOfArpTpaCase>>, Augmentation<DstOfArpTpaCase>> augmentation = Collections.emptyMap();

    public DstOfArpTpaCaseBuilder() {
    }
    public DstOfArpTpaCaseBuilder(org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxmOfArpTpaGrouping arg) {
        this._ofArpTpa = arg.isOfArpTpa();
    }

    public DstOfArpTpaCaseBuilder(DstOfArpTpaCase base) {
        this._ofArpTpa = base.isOfArpTpa();
        if (base instanceof DstOfArpTpaCaseImpl) {
            DstOfArpTpaCaseImpl impl = (DstOfArpTpaCaseImpl) base;
            if (!impl.augmentation.isEmpty()) {
                this.augmentation = new HashMap<>(impl.augmentation);
            }
        } else if (base instanceof AugmentationHolder) {
            @SuppressWarnings("unchecked")
            Map<Class<? extends Augmentation<DstOfArpTpaCase>>, Augmentation<DstOfArpTpaCase>> aug =((AugmentationHolder<DstOfArpTpaCase>) base).augmentations();
            if (!aug.isEmpty()) {
                this.augmentation = new HashMap<>(aug);
            }
        }
    }

    /**
     * Set fields from given grouping argument. Valid argument is instance of one of following types:
     * <ul>
     * <li>org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxmOfArpTpaGrouping</li>
     * </ul>
     *
     * @param arg grouping object
     * @throws IllegalArgumentException if given argument is none of valid types
    */
    public void fieldsFrom(DataObject arg) {
        boolean isValidArg = false;
        if (arg instanceof org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxmOfArpTpaGrouping) {
            this._ofArpTpa = ((org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxmOfArpTpaGrouping)arg).isOfArpTpa();
            isValidArg = true;
        }
        CodeHelpers.validValue(isValidArg, arg, "[org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxmOfArpTpaGrouping]");
    }

    public Boolean isOfArpTpa() {
        return _ofArpTpa;
    }
    
    @SuppressWarnings({ "unchecked", "checkstyle:methodTypeParameterName"})
    public <E$$ extends Augmentation<DstOfArpTpaCase>> E$$ augmentation(Class<E$$> augmentationType) {
        return (E$$) augmentation.get(CodeHelpers.nonNullValue(augmentationType, "augmentationType"));
    }

    
    public DstOfArpTpaCaseBuilder setOfArpTpa(final Boolean value) {
        this._ofArpTpa = value;
        return this;
    }
    
    public DstOfArpTpaCaseBuilder addAugmentation(Class<? extends Augmentation<DstOfArpTpaCase>> augmentationType, Augmentation<DstOfArpTpaCase> augmentationValue) {
        if (augmentationValue == null) {
            return removeAugmentation(augmentationType);
        }
    
        if (!(this.augmentation instanceof HashMap)) {
            this.augmentation = new HashMap<>();
        }
    
        this.augmentation.put(augmentationType, augmentationValue);
        return this;
    }
    
    public DstOfArpTpaCaseBuilder removeAugmentation(Class<? extends Augmentation<DstOfArpTpaCase>> augmentationType) {
        if (this.augmentation instanceof HashMap) {
            this.augmentation.remove(augmentationType);
        }
        return this;
    }

    @Override
    public DstOfArpTpaCase build() {
        return new DstOfArpTpaCaseImpl(this);
    }

    private static final class DstOfArpTpaCaseImpl implements DstOfArpTpaCase {
    
        private final Boolean _ofArpTpa;
    
        private Map<Class<? extends Augmentation<DstOfArpTpaCase>>, Augmentation<DstOfArpTpaCase>> augmentation = Collections.emptyMap();
    
        DstOfArpTpaCaseImpl(DstOfArpTpaCaseBuilder base) {
            this._ofArpTpa = base.isOfArpTpa();
            this.augmentation = ImmutableMap.copyOf(base.augmentation);
        }
    
        @Override
        public Class<DstOfArpTpaCase> getImplementedInterface() {
            return DstOfArpTpaCase.class;
        }
    
        @Override
        public Boolean isOfArpTpa() {
            return _ofArpTpa;
        }
        
        @SuppressWarnings({ "unchecked", "checkstyle:methodTypeParameterName"})
        @Override
        public <E$$ extends Augmentation<DstOfArpTpaCase>> E$$ augmentation(Class<E$$> augmentationType) {
            return (E$$) augmentation.get(CodeHelpers.nonNullValue(augmentationType, "augmentationType"));
        }
    
        private int hash = 0;
        private volatile boolean hashValid = false;
        
        @Override
        public int hashCode() {
            if (hashValid) {
                return hash;
            }
        
            final int prime = 31;
            int result = 1;
            result = prime * result + Objects.hashCode(_ofArpTpa);
            result = prime * result + Objects.hashCode(augmentation);
        
            hash = result;
            hashValid = true;
            return result;
        }
    
        @Override
        public boolean equals(Object obj) {
            if (this == obj) {
                return true;
            }
            if (!(obj instanceof DataObject)) {
                return false;
            }
            if (!DstOfArpTpaCase.class.equals(((DataObject)obj).getImplementedInterface())) {
                return false;
            }
            DstOfArpTpaCase other = (DstOfArpTpaCase)obj;
            if (!Objects.equals(_ofArpTpa, other.isOfArpTpa())) {
                return false;
            }
            if (getClass() == obj.getClass()) {
                // Simple case: we are comparing against self
                DstOfArpTpaCaseImpl otherImpl = (DstOfArpTpaCaseImpl) obj;
                if (!Objects.equals(augmentation, otherImpl.augmentation)) {
                    return false;
                }
            } else {
                // Hard case: compare our augments with presence there...
                for (Map.Entry<Class<? extends Augmentation<DstOfArpTpaCase>>, Augmentation<DstOfArpTpaCase>> e : augmentation.entrySet()) {
                    if (!e.getValue().equals(other.augmentation(e.getKey()))) {
                        return false;
                    }
                }
                // .. and give the other one the chance to do the same
                if (!obj.equals(this)) {
                    return false;
                }
            }
            return true;
        }
    
        @Override
        public String toString() {
            final MoreObjects.ToStringHelper helper = MoreObjects.toStringHelper("DstOfArpTpaCase");
            CodeHelpers.appendValue(helper, "_ofArpTpa", _ofArpTpa);
            CodeHelpers.appendValue(helper, "augmentation", augmentation.values());
            return helper.toString();
        }
    }
}
